ProjectionRegistration<TReadModel, TKey> class
final
Bundles a projection with its lifecycle mode and read model store.
Used by ProjectionRegistry to manage registered projections.
Constructors
-
ProjectionRegistration({required ProjectionBase<
TReadModel, TKey> projection, required ProjectionLifecycle lifecycle, required ReadModelStore<TReadModel, TKey> readModelStore}) -
Creates a projection registration with the given configuration.
const
Properties
-
handledEventTypes
→ Set<
Type> -
The event types handled by the registered projection.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lifecycle → ProjectionLifecycle
-
Whether this projection runs inline or async.
final
-
projection
→ ProjectionBase<
TReadModel, TKey> -
The projection implementation.
final
- projectionName → String
-
The unique name of the registered projection.
no setter
-
readModelStore
→ ReadModelStore<
TReadModel, TKey> -
The store for the projection's read models.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handles(
Type eventType) → bool -
Whether the registered projection handles the given
eventType. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited